# DSPy <> GEPA

[dspy_adapter.py](dspy_adapter.py) provides an example adapter to allow GEPA to optimize the signature instructions of any DSPy program. The most up-to-date version of this adapter is live in the DSPy repository at [gepa_utils.py](https://github.com/stanfordnlp/dspy/blob/main/dspy/teleprompt/gepa/gepa_utils.py).

> The best way to use this adapter is from within DSPy itself.

Extensive tutorials on using GEPA with DSPy are available at [dspy.GEPA tutorials](https://dspy.ai/tutorials/gepa_ai_program/).